==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/ufo/dialogs_es.lua <==

dialogId("ufo-v-znicilo", "font_big", "We must be getting near the end of our mission. This is surely the UFO that destroyed our house.")
dialogStr("Debemos de estar llegando cerca del final de nuestra misión. Esto es seguramente el OVNI.")


dialogId("ufo-m-osmy", "font_small", "Are you sure? This is only the eighth level.")
dialogStr("¿Estás seguro? Esto es sólo el octavo nivel.")


dialogId("ufo-m-valce", "font_small", "These steel cylinders are pretty obnoxious.")
dialogStr("Esos cilindros de acero son bastante desagradables.")


dialogId("ufo-m-moc", "font_small", "There is just too much steel here.")
dialogStr("Hay demasiado acero aquí.")


dialogId("ufo-v-hur", "font_big", "It could be worse. I for one can imagine myself a room where there is nothing but steel.")
dialogStr("Podría ser peor. Yo puedo imaginarme una habitación donde no haya nada excepto acero.")


dialogId("ufo-m-ne", "font_small", "My goodness! What should I do in such a level?")
dialogStr("Oh... ¿Que haría yo en un nivel así?")


dialogId("ufo-v-vpredu", "font_big", "You would let me go in front, for a change.")
dialogStr("Deberías de dejarme ir al frente, para cambiar.")


dialogId("ufo-m-zvlastni", "font_small", "It`s interesting that this tangled steel forestalls our entry into that UFO more effectively than any security system.")
dialogStr("Es interesante que este acero enredado impidiera nuestra entrada a ese OVNI en forma más efectiva que cualquier sistema de seguridad.")


dialogId("ufo-v-rikam", "font_big", "I keep telling you that our life is controlled by some higher, strange consciousness.")
dialogStr("Te sigo diciendo que nuestra vida está controlada por alguna más alta, extraña conciencia.")


dialogId("ufo-m-vidim", "font_small", "I can see that, too. But I am not that sure it`s higher.")
dialogStr("También puedo ver eso. Pero no estoy tan seguro que sea más alta.")


dialogId("ufo-v-dovnitr", "font_big", "What can we find inside, once we manage to get there?")
dialogStr("¿Qué podemos encontrar adentro, una vez que consigamos llegar?")


dialogId("ufo-m-tajemstvi", "font_small", "Secrets of another civilization, new technologies, new sources of energy...")
dialogStr("Secretos de otra civilización, nuevas tecnologías, nuevas fuentes de energía...")


dialogId("ufo-v-zjistit0", "font_big", "Most importantly, we should try to find out why they came at all.")
dialogStr("Más importante, deberíamos tratar de encontrar porqué ellos vinieron, después de todo.")


dialogId("ufo-v-zjistit1", "font_big", "You know, most of all I wonder why they crashed just here.")
dialogStr("Tu sabes, antes que nada me pregunto porqué se han estrellado justo aquí.")


dialogId("ufo-m-tady", "font_small", "Didn`t you see it? Everything happens just here.")
dialogStr("¿No lo viste? Todo ocurre aquí mismo.")


dialogId("ufo-m-nevim", "font_small", "I don`t know why the UFOs keep crashing at our house, either.")
dialogStr("No sé porqué los OVNIs se siguen estrellando en nuestra casa, tampoco.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/ufo/dialogs_es.lua <==

dialogId("ufo-v-znicilo", "font_big", "We must be getting near the end of our mission. This is surely the UFO that destroyed our house.")
dialogStr("Debemos de estar llegando cerca del final de nuestra misión. Esto es seguramente el OVNI.")


dialogId("ufo-m-osmy", "font_small", "Are you sure? This is only the eighth level.")
dialogStr("¿Estás seguro? Esto es sólo el octavo nivel.")


dialogId("ufo-m-valce", "font_small", "These steel cylinders are pretty obnoxious.")
dialogStr("Esos cilindros de acero son bastante desagradables.")


dialogId("ufo-m-moc", "font_small", "There is just too much steel here.")
dialogStr("Hay demasiado acero aquí.")


dialogId("ufo-v-hur", "font_big", "It could be worse. I for one can imagine myself a room where there is nothing but steel.")
dialogStr("Podría ser peor. Yo puedo imaginarme una habitación donde no haya nada excepto acero.")


dialogId("ufo-m-ne", "font_small", "My goodness! What should I do in such a level?")
dialogStr("Oh... ¿Que haría yo en un nivel así?")


dialogId("ufo-v-vpredu", "font_big", "You would let me go in front, for a change.")
dialogStr("Deberías de dejarme ir al frente, para cambiar.")


dialogId("ufo-m-zvlastni", "font_small", "It’s interesting that this tangled steel forestalls our entry into that UFO more effectively than any security system.")
dialogStr("Es interesante que este acero enredado impidiera nuestra entrada a ese OVNI en forma más efectiva que cualquier sistema de seguridad.")


dialogId("ufo-v-rikam", "font_big", "I keep telling you that our life is controlled by some higher, strange consciousness.")
dialogStr("Te sigo diciendo que nuestra vida está controlada por alguna más alta, extraña conciencia.")


dialogId("ufo-m-vidim", "font_small", "I can see that, too. But I am not that sure it’s higher.")
dialogStr("También puedo ver eso. Pero no estoy tan seguro que sea más alta.")


dialogId("ufo-v-dovnitr", "font_big", "What can we find inside, once we manage to get there?")
dialogStr("¿Qué podemos encontrar adentro, una vez que consigamos llegar?")


dialogId("ufo-m-tajemstvi", "font_small", "Secrets of another civilization, new technologies, new sources of energy...")
dialogStr("Secretos de otra civilización, nuevas tecnologías, nuevas fuentes de energía...")


dialogId("ufo-v-zjistit0", "font_big", "Most importantly, we should try to find out why they came at all.")
dialogStr("Más importante, deberíamos tratar de encontrar porqué ellos vinieron, después de todo.")


dialogId("ufo-v-zjistit1", "font_big", "You know, most of all I wonder why they crashed just here.")
dialogStr("Tu sabes, antes que nada me pregunto porqué se han estrellado justo aquí.")


dialogId("ufo-m-tady", "font_small", "Didn’t you see it? Everything happens just here.")
dialogStr("¿No lo viste? Todo ocurre aquí mismo.")


dialogId("ufo-m-nevim", "font_small", "I don’t know why the UFOs keep crashing at our house, either.")
dialogStr("No sé porqué los OVNIs se siguen estrellando en nuestra casa, tampoco.")
